#include <Arduino.h>
#include <stdint.h>
#include <ComponentObject.h>
#include <RangeSensor.h>
#include <SparkFun_VL53L1X.h>
#include <vl53l1x_class.h>
#include <vl53l1_error_codes.h>
#include "SCMD.h"
#include "SCMD_config.h" //Contains #defines for common SCMD register names and values
#include "Wire.h"
#include "SparkFun_VL53L1X.h"

#define LEDPIN 13

SCMD myMotorDriver; //This creates the main object of one motor driver and connected slaves.
SFEVL53L1X distanceSensor;

void setup()
{
  Wire.begin();
  Serial.begin(115200);
  pinMode(LEDPIN, OUTPUT);

  myMotorDriver.settings.commInterface = I2C_MODE;
  myMotorDriver.settings.I2CAddress = 0x5D; //config pattern "0101" on board for address 0x5A
  myMotorDriver.settings.chipSelectPin = 10;
  while ( myMotorDriver.begin() != 0xA9 ) //Wait until a valid ID word is returned
  {
    Serial.println( "ID mismatch, trying again" );
    delay(500);
  }
  while ( myMotorDriver.ready() == false );
  while ( myMotorDriver.busy() );
  myMotorDriver.enable();
  if (distanceSensor.begin() != 0) //Begin returns 0 on a good init
  {
    Serial.println("Sensor failed to begin. Please check wiring. Freezing...");
    while (1)
      ;
  }
}

void loop()
{
  Serial.println('inside loop!');
  int wheel_vel;  //linear velocity of the robot
  int left_vel;   //left wheel velocity
  int right_vel;  //right wheel velocity
  float cal_factor; //calibration factor
  digitalWrite( LEDPIN, 0 );
  digitalWrite( LEDPIN, 1 );

  // for the TOF sensor measurements
  distanceSensor.startRanging(); //Write configuration bytes to initiate measurement
  while (!distanceSensor.checkForDataReady())
  {
    delay(1);
  }
  int distance = distanceSensor.getDistance(); //Get the result of the measurement from the sensor
  distanceSensor.clearInterrupt();
  distanceSensor.stopRanging();
  Serial.println(distance);

  // conditional statments
  if (distance < 200)
  {
    Serial.println('inside conditional!');

    // controlling the motors
    cal_factor = (float)52.0 / 60.0;
    wheel_vel = 100;
    right_vel = wheel_vel;
    left_vel = cal_factor * wheel_vel;

    //go back and turn
    myMotorDriver.setDrive( 0, 1, left_vel); //Drive motor 0 - Left wheel
    myMotorDriver.setDrive( 1, 0, right_vel); //Drive motor 1 - Right wheel
    delay(1000);

    myMotorDriver.setDrive( 0, 0, left_vel); //Drive motor 0 - Left wheel
    myMotorDriver.setDrive( 1, 0, right_vel); //Drive motor 1 - Right wheel
    delay(1000);

    //stop
    myMotorDriver.setDrive( 0, 0, 0); //Drive motor 0 - Left wheel
    myMotorDriver.setDrive( 1, 1, 0); //Drive motor 1 - Right wheel
    delay(5000);
  }
  else
  {
    // controlling the motors
    cal_factor = (float)52.0 / 60.0;
    wheel_vel = 100;
    right_vel = wheel_vel;
    left_vel = cal_factor * wheel_vel;

    //go straight
    myMotorDriver.setDrive( 0, 0, left_vel); //Drive motor 0 - Left wheel
    myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
    delay(5000);
  }
}
